/**
 * Copyright (c) 2009-2012, Netbout.com
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met: 1) Redistributions of source code must retain the above
 * copyright notice, this list of conditions and the following
 * disclaimer. 2) Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following
 * disclaimer in the documentation and/or other materials provided
 * with the distribution. 3) Neither the name of the NetBout.com nor
 * the names of its contributors may be used to endorse or promote
 * products derived from this software without specific prior written
 * permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.netbout.spi.client;

import java.net.URI;
import java.util.List;

/**
 * Response generated by client.
 *
 * @author Yegor Bugayenko (yegor@netbout.com)
 * @version $Id: RestResponse.java 2159 2012-04-03 05:45:07Z guard $
 */
interface RestResponse {

    /**
     * Fail this response with the given reason.
     * @param reason The reason
     */
    void fail(String reason);

    /**
     * This status code is expected (exception will be thrown if actual code
     * doesn't match).
     * @param code The code
     * @return This object
     */
    RestResponse assertStatus(int code);

    /**
     * This XPath is expected in response body (exception will be thrown
     * if actual body doesn't match).
     * @param xpath The path
     * @return This object
     */
    RestResponse assertXPath(String xpath);

    /**
     * Get value from the retrieved XML by XPath query.
     * @param query The XPath query
     * @return The value found
     */
    List<String> xpath(String query);

    /**
     * Get location header, if it exists (exception otherwise).
     * @return The value of it
     */
    URI location();

    /**
     * Get header by name (throw exception if absent or not alone).
     * @param name Name of HTTP header
     * @return The value of it
     */
    String header(String name);

    /**
     * Create new client with a new URI, retrieved from LINK element.
     * @param rel Rel name of the link
     * @return New client
     */
    RestClient rel(String rel);

}
